<?php
namespace Teknisa\FAI\Modules\Tabelas\Controllers;

use \Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DTO\Response\Error;
use \Zeedhi\Framework\DataSource\DataSet;
use \Zeedhi\Framework\DataSource\FilterCriteria;
use \Zeedhi\Framework\DataSource\Manager;
use \Zeedhi\Framework\DataSource\ParameterBag;
use \Teknisa\GER\Services\CrudService;
use \Teknisa\GER\Utilities\Messages;

class Fai00600ExcecoesPorDia extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $environment;
    protected $crudService;
    protected $parameterBag;
    protected $dataSourceName;
    protected $dataSourceManager;
    protected $parameterBagColumns;

    public function __construct($crudService, $parameterBag, $environment, $dataSourceManager, Messages $messages) {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment  = $environment;
        $this->dataSourceManager  = $dataSourceManager;
        $this->messages = $messages;
    }

    public function retornaExcecoesPorDia(DTO\Request\Filter $request, DTO\Response $response) {

        $conditions = $request->getFilterCriteria()->getConditions();
		
		
		$codFilial = $this->getFilterValueOf($conditions, 'CDFILIAL');
		$codCliente = $this->getFilterValueOf($conditions, 'CDCLIENTE');
		$codServfili = $this->getFilterValueOf($conditions, 'CDSERVFILI');
		
		$filter = array(
			array(
				"columnName" => "CDFILIAL",
				"operator" => "=",
				"value" => $codFilial
			),
			array(
				"columnName" => "CDCLIENTE",
				"operator" => "=",
				"value" => $codCliente
			),
			array(
				"columnName" => "CDSERVFILI",
				"operator" => "=",
				"value" => $codServfili
			),
			array(
				"columnName" => "NRORG",
				"operator" => "=",
				"value" => $this->environment->getNrOrgTrab()
			)
		);

        $this->dataSourceName = "fai00600_max_servclie_histservfatu";
		$filterCriteria = new FilterCriteria($this->dataSourceName, $filter);

        $this->parameterBagColumns = array("CDCLIENTE", "CDSERVFILI", 'CDFILIAL');
        $newFilter = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $dataSet = $this->dataSourceManager->findBy($newFilter);
        $excecao = current($dataSet->getRows());

        $data = array();

        $diasSemana = array(
			"SEG" => "SEGUNDA-FEIRA",
			"TER" => "TERÇA-FEIRA",
			"QUA" => "QUARTA-FEIRA",
			"QUI" => "QUINTA-FEIRA",
			"SEX" => "SEXTA-FEIRA",
			"SAB" => "SÁBADO",
			"DOM" => "DOMINGO",
			"FER" => "FERIADO"
        );

        foreach ($diasSemana as $key => $value) {
        	$data[] = array(
        		"DIADASEMANA" => $value,
        		"CDDIADASEMANA" => $key,
        		"VRSERVFAT" => $excecao["VRFATU".$key."HIS"] !== null ? $excecao["VRFATU".$key."HIS"] : 0,
        		"QTEFETMIN" => $excecao["QTEFETMIN".$key] !== null ? $excecao["QTEFETMIN".$key] : 0,
        		"DSPRODEMIS" => $excecao["DSPRODEMIS".$key] !== null ? $excecao["DSPRODEMIS".$key] : null,
        		"CDFILIAL" => $excecao['CDFILIAL'],
        		"CDCLIENTE" => $excecao['CDCLIENTE'],
        		"CDSERVFILI" => $excecao['CDSERVFILI']
        	);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet ('fai00600_retorna_excecoes_por_dia', $data));
    }
    
    /*
    *	Função criada para retornar o valor referente ao nome do filtro
    *	independente da ordem em que for enviado no array.
    *
    *	@param {array} $array - Array do qual será extraído o valor.
    *	@param {string} $columnName - Nome da coluna da qual será extraida o valor.
    */
    public function getFilterValueOf($array, $columnName){
		$value = array_filter($array, function($element) use ($columnName){
			return $element['columnName'] == $columnName;
		});
		
		$value = reset($value)['value'];
		
		return $value;
    }
}